@@ -9,7 +9,6 @@ def save_pkl(data, dest):
     with open(dest, 'wb') as f:
         pickle.dump(data, f)
 
-@lru_cache(500)
 def load_pkl(dest):
     try:
         with open(dest, 'rb') as f:
@@ -59,14 +58,14 @@ class QuickDB:
 
     def getIDX(self):
         idx = load_pkl(os.path.join(self.path, 'ts/IDX.data'))
-        idx.index = idx.index.map(lambda x : x.strftime("%Y%m%d"))
+        try:
+            idx.index = idx.index.map(lambda x : x.strftime("%Y%m%d"))
+        except:
+            pass
         return idx
     
-    def getBdays(self, stringify=True, inverted=False):
-        if stringify:
-            _ = self.getIDX().index.map(lambda x : x.strftime("%Y%m%d"))
-        else:
-            _ = self.getIDX().index
+    def getBdays(self, inverted=False):
+        _ = self.getIDX().index
         if inverted:
             return {v:i for i, v in enumerate(_)}
         else:
